@@ -1,6 +1,6 @@
 package POE::Component::Metabase::Relay::Server::Queue;
 BEGIN {
-  $POE::Component::Metabase::Relay::Server::Queue::VERSION = '0.18';
+  $POE::Component::Metabase::Relay::Server::Queue::VERSION = '0.20';
 }
 
 # ABSTRACT: Submission queue for the metabase relay
@@ -9,6 +9,7 @@ use strict;
 use warnings;
 use POE qw[Component::EasyDBI];
 use POE::Component::Client::HTTP;
+use POE::Component::Resolver;
 use POE::Component::Metabase::Client::Submit;
 use CPAN::Testers::Report     ();
 use Metabase::User::Profile   ();
@@ -61,7 +62,7 @@ has 'profile' => (
   isa => 'Metabase::User::Profile',
   required => 1,
 );
- 
+
 has 'secret' => (
   is => 'ro',
   isa => 'Metabase::User::Secret',
@@ -149,6 +150,13 @@ has _http_alias => (
   writer => '_set_http_alias',
 );
 
+has _resolver => (
+  is => 'ro',
+  isa => 'Str',
+  init_arg => undef,
+  writer => '_set_resolver',
+);
+
 has '_processing' => (
   is => 'ro',
   isa => 'HashRef',
@@ -173,12 +181,15 @@ sub _build__uuid {
 sub spawn {
   shift->new(@_);
 }
- 
+
 sub START {
   my ($kernel,$self) = @_[KERNEL,OBJECT];
   $self->_build_table;
   $kernel->yield( 'do_vacuum' );
-  if ( ! $self->multiple ) {
+  if ( $self->multiple ) {
+    $self->_set_resolver( POE::Component::Resolver->new() );
+  }
+  else {
     $self->_set_http_alias( join '-', __PACKAGE__, $self->get_session_id );
     POE::Component::Client::HTTP->spawn(
       Alias           => $self->_http_alias,
@@ -234,7 +245,7 @@ event 'shutdown' => sub {
   my ($kernel,$self) = @_[KERNEL,OBJECT];
   $kernel->alarm_remove_all();
   $kernel->post( $self->_easydbi->ID, 'shutdown' );
-  $kernel->post( 
+  $kernel->post(
     $self->_http_alias,
     'shutdown',
   );
@@ -301,9 +312,9 @@ event '_queue_db_result' => sub {
       fact    => $report,
       uri     => $self->uri->as_string,
       context => [ $row->{id}, $row->{attempts}, $self->_time ],
-      ( $self->multiple ? () : ( http_alias => $self->_http_alias ) ),
+      ( $self->multiple ? ( resolver => $self->_resolver ) : ( http_alias => $self->_http_alias ) ),
     );
-    
+
   }
   return;
 };
@@ -379,9 +390,9 @@ sub _decode_fact {
 }
 
 no MooseX::POE;
- 
+
 __PACKAGE__->meta->make_immutable;
- 
+
 1;
 
 
@@ -394,7 +405,7 @@ POE::Component::Metabase::Relay::Server::Queue - Submission queue for the metaba
 
 =head1 VERSION
 
-version 0.18
+version 0.20
 
 =head1 DESCRIPTION
 
@@ -468,7 +479,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Chris Williams.
+This software is copyright (c) 2011 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
